##
##  hydra.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_hydra_base 2.2.0
%define       V_hydra_snap 20240213

#   package information
Name:         hydra
Summary:      OpenID/OAUTH2 Provider
URL:          https://ory.am/hydra
Vendor:       Ory
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      Apache
Version:      %{V_hydra_base}.%{V_hydra_snap}
Release:      20240213

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/hydra/hydra-%{V_hydra_snap}.tar.xz
Source1:      rc.hydra
Source2:      hydra.yaml

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Hydra is a scalable in-memory OAUTH2 and OpenID Connect service that
    integrates with every Identity Provider you can imagine.

%track
    prog hydra:release = {
        version   = %{V_hydra_base}
        url       = https://github.com/ory/hydra/releases
        regex     = v(\d+\.\d+\.\d+)\.tar\.gz
    }
    prog hydra:snapshot = {
        version   = %{V_hydra_snap}
        url       = http://download.openpkg.org/components/versioned/hydra/
        regex     = hydra-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n hydra

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/ory/hydra
    go build -v -o hydra

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/hydra \
        $RPM_BUILD_ROOT%{l_prefix}/var/hydra/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/hydra/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/hydra/db

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/ory/hydra/hydra \
        $RPM_BUILD_ROOT%{l_prefix}/bin/hydra

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.hydra} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE hydra.yaml} $RPM_BUILD_ROOT%{l_prefix}/etc/hydra/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/hydra/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/etc/hydra' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/hydra/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} hydra status 2>/dev/null`
        [ ".$hydra_active" = .yes ] && %{l_rc} hydra restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    if [ $1 -eq 0 ]; then
        %{l_rc} hydra stop 2>/dev/null
        rm -f  $RPM_INSTALL_PREFIX/var/hydra/log/* >/dev/null 2>&1 || true
        rm -f  $RPM_INSTALL_PREFIX/var/hydra/run/* >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/hydra/db/*  >/dev/null 2>&1 || true
    fi
    exit 0

